@@ -5,6 +5,9 @@ CLI_CONFIG = {
     },
     "acct_key": {"os": "ACCT_KEY", "subcommands": ["encrypt", "decrypt"]},
     "acct_file": {"os": "ACCT_FILE", "subcommands": ["encrypt", "decrypt"]},
+    "extras": {
+        "render": "json",
+    },
     "crypto_plugin": {"subcommands": ["encrypt", "decrypt"]},
     "output": {"source": "rend", "subcommands": ["decrypt"]},
     "output_file": {"subcommands": ["encrypt"]},
@@ -18,6 +21,10 @@ CONFIG = {
         "default": None,
         "help": "The key to encrypt the file with, if no key is passed a key will be generated and displayed on after the encrypted file is created",
     },
+    "extras": {
+        "default": None,
+        "help": "Additional arbitrary configuration values as a json string",
+    },
     "crypto_plugin": {
         "default": "fernet",
         "help": "The crypto plugin to use with acct",
