@@ -4,16 +4,17 @@ import msgpack
 
 
 def generate_key(hub):
-    return cryptography.fernet.Fernet.generate_key().decode()
+    key = cryptography.fernet.Fernet.generate_key()
+    return key.decode("utf-8")
 
 
-def encrypt(hub, data, key):
+def encrypt(hub, data, key: str):
     fernet = cryptography.fernet.Fernet(key)
     raw = msgpack.dumps(data)
     return fernet.encrypt(raw)
 
 
-def decrypt(hub, data, key):
+def decrypt(hub, data, key: str):
     fernet = cryptography.fernet.Fernet(key)
     raw = fernet.decrypt(data)
     serialized = msgpack.loads(raw)
